==> xemacs-sumo-21.20060510p0-mule.tgz: lib/xemacs/xemacs-packages/lisp/eshell/custom-load.el <==
;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'eshell-alias '("em-alias"))
(custom-add-loads 'eshell-mode '("esh-mode"))
(custom-add-loads 'eshell-proc '("esh-proc"))
(custom-add-loads 'eshell-pred '("em-pred"))
(custom-add-loads 'eshell-var '("esh-var"))
(custom-add-loads 'eshell-ls '("em-ls"))
(custom-add-loads 'applications '("eshell"))
(custom-add-loads 'eshell-io '("esh-io"))
(custom-add-loads 'eshell-hist '("em-hist"))
(custom-add-loads 'eshell-dirs '("em-dirs"))
(custom-add-loads 'eshell-term '("em-term"))
(custom-add-loads 'eshell-test '("esh-test"))
(custom-add-loads 'eshell-module '("esh-groups" "esh-module"))
(custom-add-loads 'eshell-smart '("em-smart"))
(custom-add-loads 'eshell-basic '("em-basic"))
(custom-add-loads 'eshell-cmd '("esh-cmd"))
(custom-add-loads 'eshell-arg '("esh-arg"))
(custom-add-loads 'eshell-ext '("esh-ext"))
(custom-add-loads 'eshell-cmpl '("em-cmpl"))
(custom-add-loads 'eshell-banner '("em-banner"))
(custom-add-loads 'eshell-glob '("em-glob"))
(custom-add-loads 'eshell-prompt '("em-prompt"))
(custom-add-loads 'pcomplete '("em-cmpl"))
(custom-add-loads 'eshell '("eshell" "esh-arg" "esh-cmd" "esh-ext" "esh-io" "esh-mode" "esh-module" "esh-opt" "esh-proc" "esh-test" "esh-util" "esh-var"))
(custom-add-loads 'eshell-util '("esh-util"))
(custom-add-loads 'eshell-rebind '("em-rebind"))
(custom-add-loads 'eshell-script '("em-script"))
(custom-add-loads 'eshell-unix '("em-unix"))

;;; custom-load.el ends here

==> xemacs-sumo-21.20100727p1-mule.tgz: lib/xemacs/xemacs-packages/lisp/eshell/custom-load.el <==
;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'eshell-alias '("em-alias"))
(custom-add-loads 'eshell-mode '("esh-mode"))
(custom-add-loads 'eshell-proc '("esh-proc"))
(custom-add-loads 'eshell-pred '("em-pred"))
(custom-add-loads 'eshell-var '("esh-var"))
(custom-add-loads 'eshell-ls '("em-ls"))
(custom-add-loads 'applications '("eshell"))
(custom-add-loads 'eshell-io '("esh-io"))
(custom-add-loads 'eshell-hist '("em-hist"))
(custom-add-loads 'eshell-dirs '("em-dirs"))
(custom-add-loads 'eshell-term '("em-term"))
(custom-add-loads 'eshell-test '("esh-test"))
(custom-add-loads 'eshell-module '("em-alias" "em-banner" "em-basic" "em-cmpl" "em-dirs" "em-glob" "em-hist" "em-ls" "em-pred" "em-prompt" "em-rebind" "em-script" "em-smart" "em-term" "em-unix" "em-xtra" "esh-module"))
(custom-add-loads 'eshell-smart '("em-smart"))
(custom-add-loads 'eshell-basic '("em-basic"))
(custom-add-loads 'eshell-cmd '("esh-cmd"))
(custom-add-loads 'eshell-arg '("esh-arg"))
(custom-add-loads 'eshell-ext '("esh-ext"))
(custom-add-loads 'eshell-cmpl '("em-cmpl"))
(custom-add-loads 'eshell-banner '("em-banner"))
(custom-add-loads 'eshell-glob '("em-glob"))
(custom-add-loads 'eshell-prompt '("em-prompt"))
(custom-add-loads 'pcomplete '("em-cmpl"))
(custom-add-loads 'eshell '("esh-arg" "esh-cmd" "esh-ext" "esh-io" "esh-mode" "esh-module" "esh-opt" "esh-proc" "esh-test" "esh-util" "esh-var" "eshell"))
(custom-add-loads 'eshell-util '("esh-util"))
(custom-add-loads 'eshell-rebind '("em-rebind"))
(custom-add-loads 'eshell-script '("em-script"))
(custom-add-loads 'eshell-unix '("em-unix"))

;;; custom-load.el ends here
